NoOpConnectivityCache class

No-op cache for tests or when caching is disabled via ConnectivityConfig.

Implemented types

Constructors

NoOpConnectivityCache()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read() Future<ConnectivityResultModel?>
override
toString() String
A string representation of this object.
inherited
write(ConnectivityResultModel result) Future<void>
override

Operators

operator ==(Object other) bool
The equality operator.
inherited