ConnectivityChecking class final
First state — emitted immediately before the first probe completes. UI should show a neutral/loading indicator.
- Inheritance
-
- Object
- ConnectivityState
- ConnectivityChecking
- Available extensions
Constructors
- ConnectivityChecking()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isOnline → bool
-
Available on ConnectivityState, provided by the ConnectivityStateX extension
Whether the current state represents an active internet connection.no setter - resultOrNull → ConnectivityResultModel?
-
Available on ConnectivityState, provided by the ConnectivityStateX extension
Safe accessor — returns null when not in ConnectivityLoaded state.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited