ConnectivityLoaded class final

First probe (or cache read) returned a result. This is the steady state — all subsequent emissions are this type.

Inheritance
Available extensions

Constructors

ConnectivityLoaded(ConnectivityResultModel result)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isCaptivePortal bool
no setter
isOnline bool
no setter
isOnline bool

Available on ConnectivityState, provided by the ConnectivityStateX extension

Whether the current state represents an active internet connection.
no setter
isSlowConnection bool
no setter
latencyMs int?
no setter
networkType NetworkType
no setter
quality ConnectionQuality
no setter
result ConnectivityResultModel
final
resultOrNull ConnectivityResultModel?

Available on ConnectivityState, provided by the ConnectivityStateX extension

Safe accessor — returns null when not in ConnectivityLoaded state.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited