showForSlowConnection property
Whether to show the banner for slow connections too (not just offline).
Implementation
final bool showForSlowConnection;
Whether to show the banner for slow connections too (not just offline).
final bool showForSlowConnection;